@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Resolver;
-$Template::Resolver::VERSION = '1.15';
+$Template::Resolver::VERSION = '1.16';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -182,13 +182,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.15
-
-=head1 SYNOPSIS
-
-  use Template::Resolver;
-  my $resolver = Template::Resolver->new($entity);
-  $resolver->resolve(file => '/path/to/file', key => 'REPLACEME');
+version 1.16
 
 =head1 DESCRIPTION
 
@@ -298,4 +292,58 @@ L<https://github.com/lucastheisen/template-resolver|https://github.com/lucasthei
 
 =back
 
+=head1 SYNOPSIS
+  # Basic example
+  use Template::Resolver;
+  my $resolver = Template::Resolver->new($entity);
+  $resolver->resolve(file => '/path/to/file', key => 'REPLACEME');
+
+  # More complete example
+  use Template::Resolver;
+
+  $java_properties_file = <<'EOF';
+
+    # Simple value that will error if not present
+    server_port = ${TEMPLATE{app.port}}
+
+    # Simple value with a default (no error if not present)
+    context_path = ${TEMPLATE{app.context_path:/myapp}}
+
+    # Get an env var
+    http_proxy = ${TEMPLATE_env{HTTP_PROXY}}
+
+    # Translate a cygwin path with error if not present
+    module_jar = ${TEMPLATE_os{app.module_addon1}}
+
+    # Translate a cygwin path with default
+    module_jar = ${TEMPLATE_os{app.module_addon2:/var/local/lib/mymodule.jar}}
+
+    # Escape some xml (with blank default)
+    html_header = ${TEMPLATE_xml_escape{app.header:}}
+
+    # Run some perl
+    https_enabled = ${TEMPLATE_perl{ property(app.use_https) ? 'true' : 'false'}}
+    https_proxy = ${TEMPLATE_perl{ sprintf( 'https://%s:%d/', $ENV{HTTPS_PROXY_HOST}, $ENV{HTTPS_PROXY_PORT} )}}
+
+    # Custom stuff
+    db_user = ${TEMPLATE_customfetch{ 'dbuser' }}
+
+  EOF
+
+  my $entity = {
+      app => {
+          port => 80,
+          module_addon1 => '/var/local/lib/mymodule.jar',
+          use_https => 0,
+      }
+  };
+
+  my $resolver = Template::Resolver->new( $entity, additional_transforms => {
+      customfetch => sub {
+          #Do something here
+          return 'mydbuser';
+      }
+  });
+  my $transformed_result = $resolver->resolve( content => $java_properties_file );
+
 =cut
